@@ -22,11 +22,6 @@ namespace Botan {
 
 class RandomNumberGenerator;
 
-/**
-* The two types of signature format supported by Botan.
-*/
-enum Signature_Format { IEEE_1363, DER_SEQUENCE };
-
 /**
 * Public Key Encryptor
 * This is the primary interface for public key encryption
